@@ -376,7 +376,7 @@ def sankey(source, target, value,labels_sr,labels_tr,label_show=False, opacity_i
           value = value,
           color = color_link
       ))])
-    img_bytes = fig.to_image(format="png",height=600,width=800)
+    img_bytes = fig.to_image(format="png",height=600,width=800,engine='kaleido')
     return Image(img_bytes)
     
 def funnel(labels, values, opacity_ins=0.5):
@@ -419,5 +419,5 @@ def funnel(labels, values, opacity_ins=0.5):
     
 
     
-    img_bytes = fig.to_image(format="png",height=600,width=800)
+    img_bytes = fig.to_image(format="png",height=600,width=800,engine='kaleido')
     return Image(img_bytes)
\ No newline at end of file
