@@ -5,7 +5,7 @@ import matplotlib.pyplot as plt
 from yellowbrick.classifier import discrimination_threshold
 from sklearn.metrics import PrecisionRecallDisplay
 
-def fis_metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_umbral=False,model=None,x=None,y=None):
+def metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_umbral=False,model=None,x=None,y=None):
     """
     umbral --> threshold de % de probabilidad a partir de la cual es True (1)  
     
@@ -54,7 +54,7 @@ def fis_metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_umbral=F
         plt.show()
     print('\n====================================================================')
     
-def fis_metric_max_roi(real,scoring, salida = 'grafico',itn=0,ifp=-15,ifn=-85,itp=85):
+def metric_max_roi(real,scoring, salida = 'grafico',itn=0,ifp=-15,ifn=-85,itp=85):
     """
     salida <> "grafico" devuelve valor numérico max ROI, para automatizaciones
     #DEFINIMOS LA MATRIZ DE IMPACTO
